.. _installation:

============
Installation
============

.. highlight:: bash

Windows
=======

``loggertodb`` is just a single executable, ``loggertodb.exe``. You
download it and run it; there's no installer.

Download ``loggertodb.exe`` from
https://github.com/openmeteo/loggertodb/releases/.

Linux
=====

Simply execute this::

    pip3 install loggertodb

